@@ -3,8 +3,8 @@ from typing import Type, TypeVar
 import typer
 
 
-T = TypeVar('T')
+T = TypeVar("T")
 
 
 def inject_from_ctx(klass: Type[T], ctx: typer.Context) -> T:
-    return ctx.obj['container'].get(klass)
+    return ctx.obj["container"].get(klass)
