@@ -6,9 +6,7 @@ class Database:
         kwargs = {}
         if str(db_url).startswith("sqlite"):
             kwargs["poolclass"] = pool.SingletonThreadPool
-            kwargs['connect_args'] = {
-                'check_same_thread': False
-            }
+            kwargs["connect_args"] = {"check_same_thread": False}
         self._engine = create_engine(db_url, echo=True, future=True, **kwargs)
         self.session_factory = orm.sessionmaker(
             autocommit=False,
@@ -19,6 +17,7 @@ class Database:
     def disconnect(self):
         pass
 
+
 #    @contextmanager
 #    def session(self) -> Callable[..., AbstractContextManager[Session]]:
 #        session: Session = self._session_factory()
