@@ -10,7 +10,7 @@ def test_stats_wo_auth(fa_data_client):
     assert response.status_code == status.HTTP_200_OK
 
     entries = response.json()
-    print(f'{entries=}')
+    print(f"{entries=}")
     assert len(entries) == 4
 
 
@@ -22,5 +22,5 @@ def test_stats_w_auth(fa_data_client, read_token: auth.AccessToken):
     assert response.status_code == status.HTTP_200_OK
 
     entries = response.json()
-    print(f'{entries=}')
+    print(f"{entries=}")
     assert len(entries) == 4
