@@ -1,4 +1,4 @@
-'''Handle calls and json convertions.'''
+"""Handle calls and json convertions."""
 import json
 from typing import Dict
 from fastapi import status
@@ -6,12 +6,9 @@ from karp import auth
 
 
 def get_json(
-    client,
-    path: str,
-    expected_status_code: int = status.HTTP_200_OK,
-    **kwargs
+    client, path: str, expected_status_code: int = status.HTTP_200_OK, **kwargs
 ):
-    '''Call the get on the client with the given path.
+    """Call the get on the client with the given path.
 
     Assert that the status_code is ok.
     Then load the json response.
@@ -22,10 +19,10 @@ def get_json(
 
     Returns:
         [type] -- [description]
-    '''
+    """
     response = client.get(path, **kwargs)
     response_json = response.json()
-    print(f'{response_json=}')
+    print(f"{response_json=}")
     assert response.status_code == expected_status_code
     return response_json
 
@@ -38,9 +35,11 @@ def add_entries(
     for resource, _entries in entries.items():
         for entry in _entries:
             response = client.post(
-                f'/entries/{resource}/add',
-                json={'entry': entry},
+                f"/entries/{resource}/add",
+                json={"entry": entry},
                 headers=access_token.as_header(),
             )
-            assert response.status_code == 201, f'Response(status_code={response.status_code}, json={response.json()})'
+            assert (
+                response.status_code == 201
+            ), f"Response(status_code={response.status_code}, json={response.json()})"
     return client
